Authors
=======

This file contains the list of people involved in the development
of matchbox along its history.

* Grzegorz Śliwiński
* Michał Pawłowski

Language consultants
--------------------

* Michael Sweeney
